# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ai.stigmer.agentic.agentexecution.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2
from ai.stigmer.agentic.agentexecution.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2


class AgentExecutionQueryControllerStub(object):
    """AgentExecutionQueryController handles read operations for agent executions.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.get = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController/get',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.AgentExecutionId.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
                _registered_method=True)
        self.list = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController/list',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.ListAgentExecutionsRequest.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.AgentExecutionList.FromString,
                _registered_method=True)
        self.listBySession = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController/listBySession',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.ListAgentExecutionsBySessionRequest.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.AgentExecutionList.FromString,
                _registered_method=True)
        self.subscribe = channel.unary_stream(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController/subscribe',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.AgentExecutionId.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
                _registered_method=True)
        self.getArtifactDownloadUrl = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController/getArtifactDownloadUrl',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetArtifactDownloadUrlRequest.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetArtifactDownloadUrlResponse.FromString,
                _registered_method=True)
        self.getArtifactContent = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController/getArtifactContent',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetArtifactContentRequest.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetArtifactContentResponse.FromString,
                _registered_method=True)
        self.getSessionUsageReport = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController/getSessionUsageReport',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetSessionUsageReportInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetSessionUsageReportOutput.FromString,
                _registered_method=True)
        self.getAgentUsageReport = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController/getAgentUsageReport',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetAgentUsageReportInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetAgentUsageReportOutput.FromString,
                _registered_method=True)
        self.getOrgUsageReport = channel.unary_unary(
                '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController/getOrgUsageReport',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetOrgUsageReportInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetOrgUsageReportOutput.FromString,
                _registered_method=True)


class AgentExecutionQueryControllerServicer(object):
    """AgentExecutionQueryController handles read operations for agent executions.
    """

    def get(self, request, context):
        """Get a single agent execution by ID.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """List all agent executions with pagination and optional filtering.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def listBySession(self, request, context):
        """List all executions in a specific session.
        Authorization is handled in handler via FGA query for authorized agent_execution_ids,
        then filtered by session_id. This ensures consistent authorization pattern across all list operations.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def subscribe(self, request, context):
        """Subscribe to real-time execution updates (streaming).
        Authorization is handled by the FJ model via proto configuration.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getArtifactDownloadUrl(self, request, context):
        """─────────────────────────────────────────────────────────────────────────────
        Artifact Lifecycle Operations

        These RPCs support downloading artifacts created by agent executions.
        ─────────────────────────────────────────────────────────────────────────────

        Get a presigned download URL for an execution artifact.

        Returns a time-limited URL for downloading an artifact published by
        an agent during execution. The URL can be used with a simple HTTP GET
        request without authentication.

        ## Authorization

        Requires can_view permission on the execution. This ensures users can
        only download artifacts from executions they have access to.

        ## Security

        The storage_key is validated to ensure it belongs to the specified
        execution. Keys must start with "artifacts/{execution_id}/" to prevent
        path traversal attacks.

        ## URL Expiration

        Download URLs expire after 7 days (configurable). After expiration,
        call this endpoint again to get a fresh URL.

        ## Use Cases

        - CLI downloading agent-created files
        - Web UI providing download links for artifacts
        - Refreshing expired download URLs

        ## Example Flow

        1. Get execution via AgentExecutionQueryController.get
        2. Find artifact in status.artifacts[]
        3. Call getArtifactDownloadUrl with execution_id and storage_key
        4. Use returned download_url for HTTP GET

        @since Artifact Lifecycle (Attachments & Artifacts)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getArtifactContent(self, request, context):
        """Read the raw content of an execution artifact.

        Returns artifact bytes through the Stigmer API, eliminating CORS
        concerns for SDK consumers who need to read content programmatically
        (e.g., YAML parsing for resource detection, in-app preview rendering).

        For direct file downloads, use getArtifactDownloadUrl instead — it
        returns a presigned R2 URL that avoids proxying bytes through the server.

        ## Authorization

        Requires can_view permission on the execution. This ensures users can
        only read artifacts from executions they have access to.

        ## Security

        The storage_key is validated to ensure it belongs to the specified
        execution. Keys must start with "artifacts/{execution_id}/" to prevent
        path traversal attacks.

        ## Size Limit

        Content is truncated to max_bytes (default: 512 KB). The response
        includes total_size_bytes and a truncated flag so callers can decide
        whether to offer a full download via getArtifactDownloadUrl.

        ## Example Flow

        1. Get execution via AgentExecutionQueryController.get
        2. Find artifact in status.artifacts[]
        3. Call getArtifactContent with execution_id and storage_key
        4. Decode content bytes as UTF-8 for text artifacts
        5. Parse YAML to detect Stigmer resource kind (Agent, McpServer, etc.)

        @since Artifact Lifecycle (Attachments & Artifacts)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getSessionUsageReport(self, request, context):
        """─────────────────────────────────────────────────────────────────────────────
        Usage Report Operations

        These RPCs provide cost and token consumption visibility at session,
        agent, and organization levels. All data is derived from AgentExecution
        records with different aggregation scopes.
        ─────────────────────────────────────────────────────────────────────────────

        Get usage report for a session (all executions in a session).
        Returns aggregated tokens, cost, cache hit rate, and per-execution breakdown.

        Authorization is handled in handler — caller must have can_view on
        all executions in the session (same pattern as listBySession).
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getAgentUsageReport(self, request, context):
        """Get usage report for an agent (all sessions for an agent in a time range).
        Returns aggregated tokens, cost, and per-session breakdown with pagination.

        Authorization is handled in handler — caller must have can_view on the agent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def getOrgUsageReport(self, request, context):
        """Get usage report for an organization (all agents in a time range).
        Returns org-wide totals, top agents by cost, model breakdown, and daily trend.

        Authorization is handled in handler — caller must be org member.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AgentExecutionQueryControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.AgentExecutionId.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.ListAgentExecutionsRequest.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.AgentExecutionList.SerializeToString,
            ),
            'listBySession': grpc.unary_unary_rpc_method_handler(
                    servicer.listBySession,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.ListAgentExecutionsBySessionRequest.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.AgentExecutionList.SerializeToString,
            ),
            'subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.subscribe,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.AgentExecutionId.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.SerializeToString,
            ),
            'getArtifactDownloadUrl': grpc.unary_unary_rpc_method_handler(
                    servicer.getArtifactDownloadUrl,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetArtifactDownloadUrlRequest.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetArtifactDownloadUrlResponse.SerializeToString,
            ),
            'getArtifactContent': grpc.unary_unary_rpc_method_handler(
                    servicer.getArtifactContent,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetArtifactContentRequest.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetArtifactContentResponse.SerializeToString,
            ),
            'getSessionUsageReport': grpc.unary_unary_rpc_method_handler(
                    servicer.getSessionUsageReport,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetSessionUsageReportInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetSessionUsageReportOutput.SerializeToString,
            ),
            'getAgentUsageReport': grpc.unary_unary_rpc_method_handler(
                    servicer.getAgentUsageReport,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetAgentUsageReportInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetAgentUsageReportOutput.SerializeToString,
            ),
            'getOrgUsageReport': grpc.unary_unary_rpc_method_handler(
                    servicer.getOrgUsageReport,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetOrgUsageReportInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetOrgUsageReportOutput.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AgentExecutionQueryController(object):
    """AgentExecutionQueryController handles read operations for agent executions.
    """

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController/get',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.AgentExecutionId.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController/list',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.ListAgentExecutionsRequest.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.AgentExecutionList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def listBySession(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController/listBySession',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.ListAgentExecutionsBySessionRequest.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.AgentExecutionList.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController/subscribe',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.AgentExecutionId.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2.AgentExecution.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getArtifactDownloadUrl(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController/getArtifactDownloadUrl',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetArtifactDownloadUrlRequest.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetArtifactDownloadUrlResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getArtifactContent(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController/getArtifactContent',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetArtifactContentRequest.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetArtifactContentResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getSessionUsageReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController/getSessionUsageReport',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetSessionUsageReportInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetSessionUsageReportOutput.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getAgentUsageReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController/getAgentUsageReport',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetAgentUsageReportInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetAgentUsageReportOutput.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def getOrgUsageReport(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentexecution.v1.AgentExecutionQueryController/getOrgUsageReport',
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetOrgUsageReportInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2.GetOrgUsageReportOutput.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agent/v1/api.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agent/v1/api.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agent.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_spec__pb2
from ai.stigmer.agentic.agent.v1 import status_pb2 as ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_status__pb2
from ai.stigmer.commons.apiresource import metadata_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_metadata__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%ai/stigmer/agentic/agent/v1/api.proto\x12\x1b\x61i.stigmer.agentic.agent.v1\x1a&ai/stigmer/agentic/agent/v1/spec.proto\x1a(ai/stigmer/agentic/agent/v1/status.proto\x1a-ai/stigmer/commons/apiresource/metadata.proto\x1a\x1b\x62uf/validate/validate.proto\"\xbf\x02\n\x05\x41gent\x12=\n\x0b\x61pi_version\x18\x01 \x01(\tB\x1c\xbaH\x19r\x17\n\x15\x61gentic.stigmer.ai/v1R\napiVersion\x12 \n\x04kind\x18\x02 \x01(\tB\x0c\xbaH\tr\x07\n\x05\x41gentR\x04kind\x12W\n\x08metadata\x18\x03 \x01(\x0b\x32\x33.ai.stigmer.commons.apiresource.ApiResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12:\n\x04spec\x18\x04 \x01(\x0b\x32&.ai.stigmer.agentic.agent.v1.AgentSpecR\x04spec\x12@\n\x06status\x18\x05 \x01(\x0b\x32(.ai.stigmer.agentic.agent.v1.AgentStatusR\x06statusB\xbc\x01\n\x1f\x63om.ai.stigmer.agentic.agent.v1B\x08\x41piProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02\x1b\x41i.Stigmer.Agentic.Agent.V1\xca\x02\x1b\x41i\\Stigmer\\Agentic\\Agent\\V1\xe2\x02\'Ai\\Stigmer\\Agentic\\Agent\\V1\\GPBMetadata\xea\x02\x1f\x41i::Stigmer::Agentic::Agent::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agent.v1.api_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.ai.stigmer.agentic.agent.v1B\010ApiProtoP\001\242\002\004ASAA\252\002\033Ai.Stigmer.Agentic.Agent.V1\312\002\033Ai\\Stigmer\\Agentic\\Agent\\V1\342\002\'Ai\\Stigmer\\Agentic\\Agent\\V1\\GPBMetadata\352\002\037Ai::Stigmer::Agentic::Agent::V1'
  _globals['_AGENT'].fields_by_name['api_version']._loaded_options = None
  _globals['_AGENT'].fields_by_name['api_version']._serialized_options = b'\272H\031r\027\n\025agentic.stigmer.ai/v1'
  _globals['_AGENT'].fields_by_name['kind']._loaded_options = None
  _globals['_AGENT'].fields_by_name['kind']._serialized_options = b'\272H\tr\007\n\005Agent'
  _globals['_AGENT'].fields_by_name['metadata']._loaded_options = None
  _globals['_AGENT'].fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _globals['_AGENT']._serialized_start=229
  _globals['_AGENT']._serialized_end=548
# @@protoc_insertion_point(module_scope)



from ai.stigmer.agentic.agentexecution.v1 import enum_pb2 as _enum_pb2
from ai.stigmer.agentic.workflowexecution.v1 import api_pb2 as _api_pb2
from ai.stigmer.agentic.workflowexecution.v1 import enum_pb2 as _enum_pb2_1
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf import struct_pb2 as _struct_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WorkflowUpdateType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    workflow_update_type_unspecified: _ClassVar[WorkflowUpdateType]
    wf_update_status_changed: _ClassVar[WorkflowUpdateType]
    wf_update_task_started: _ClassVar[WorkflowUpdateType]
    wf_update_task_completed: _ClassVar[WorkflowUpdateType]
    wf_update_task_failed: _ClassVar[WorkflowUpdateType]
    wf_update_execution_completed: _ClassVar[WorkflowUpdateType]
    wf_update_execution_cancelled: _ClassVar[WorkflowUpdateType]
workflow_update_type_unspecified: WorkflowUpdateType
wf_update_status_changed: WorkflowUpdateType
wf_update_task_started: WorkflowUpdateType
wf_update_task_completed: WorkflowUpdateType
wf_update_task_failed: WorkflowUpdateType
wf_update_execution_completed: WorkflowUpdateType
wf_update_execution_cancelled: WorkflowUpdateType

class WorkflowExecutionId(_message.Message):
    __slots__ = ("value",)
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ...) -> None: ...

class WorkflowId(_message.Message):
    __slots__ = ("value",)
    VALUE_FIELD_NUMBER: _ClassVar[int]
    value: str
    def __init__(self, value: _Optional[str] = ...) -> None: ...

class WorkflowExecutionList(_message.Message):
    __slots__ = ("total_pages", "entries")
    TOTAL_PAGES_FIELD_NUMBER: _ClassVar[int]
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    total_pages: int
    entries: _containers.RepeatedCompositeFieldContainer[_api_pb2.WorkflowExecution]
    def __init__(self, total_pages: _Optional[int] = ..., entries: _Optional[_Iterable[_Union[_api_pb2.WorkflowExecution, _Mapping]]] = ...) -> None: ...

class ListWorkflowExecutionsRequest(_message.Message):
    __slots__ = ("page_size", "page_token", "phase", "tags")
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    PHASE_FIELD_NUMBER: _ClassVar[int]
    TAGS_FIELD_NUMBER: _ClassVar[int]
    page_size: int
    page_token: str
    phase: _enum_pb2_1.ExecutionPhase
    tags: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, page_size: _Optional[int] = ..., page_token: _Optional[str] = ..., phase: _Optional[_Union[_enum_pb2_1.ExecutionPhase, str]] = ..., tags: _Optional[_Iterable[str]] = ...) -> None: ...

class ListWorkflowExecutionsByWorkflowRequest(_message.Message):
    __slots__ = ("workflow_id", "page_size", "page_token")
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    workflow_id: str
    page_size: int
    page_token: str
    def __init__(self, workflow_id: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class WorkflowExecutionUpdateStatusInput(_message.Message):
    __slots__ = ("execution_id", "status")
    EXECUTION_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    execution_id: str
    status: _api_pb2.WorkflowExecutionStatus
    def __init__(self, execution_id: _Optional[str] = ..., status: _Optional[_Union[_api_pb2.WorkflowExecutionStatus, _Mapping]] = ...) -> None: ...

class SubmitWorkflowApprovalInput(_message.Message):
    __slots__ = ("execution_id", "tool_call_id", "action", "comment")
    EXECUTION_ID_FIELD_NUMBER: _ClassVar[int]
    TOOL_CALL_ID_FIELD_NUMBER: _ClassVar[int]
    ACTION_FIELD_NUMBER: _ClassVar[int]
    COMMENT_FIELD_NUMBER: _ClassVar[int]
    execution_id: str
    tool_call_id: str
    action: _enum_pb2.ApprovalAction
    comment: str
    def __init__(self, execution_id: _Optional[str] = ..., tool_call_id: _Optional[str] = ..., action: _Optional[_Union[_enum_pb2.ApprovalAction, str]] = ..., comment: _Optional[str] = ...) -> None: ...

class SubscribeWorkflowExecutionRequest(_message.Message):
    __slots__ = ("execution_id",)
    EXECUTION_ID_FIELD_NUMBER: _ClassVar[int]
    execution_id: str
    def __init__(self, execution_id: _Optional[str] = ...) -> None: ...

class WorkflowExecutionUpdate(_message.Message):
    __slots__ = ("update_type", "execution", "task")
    UPDATE_TYPE_FIELD_NUMBER: _ClassVar[int]
    EXECUTION_FIELD_NUMBER: _ClassVar[int]
    TASK_FIELD_NUMBER: _ClassVar[int]
    update_type: WorkflowUpdateType
    execution: _api_pb2.WorkflowExecution
    task: _api_pb2.WorkflowTask
    def __init__(self, update_type: _Optional[_Union[WorkflowUpdateType, str]] = ..., execution: _Optional[_Union[_api_pb2.WorkflowExecution, _Mapping]] = ..., task: _Optional[_Union[_api_pb2.WorkflowTask, _Mapping]] = ...) -> None: ...

class CancelWorkflowExecutionInput(_message.Message):
    __slots__ = ("id", "reason")
    ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    id: str
    reason: str
    def __init__(self, id: _Optional[str] = ..., reason: _Optional[str] = ...) -> None: ...

class TerminateWorkflowExecutionInput(_message.Message):
    __slots__ = ("id", "reason")
    ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    id: str
    reason: str
    def __init__(self, id: _Optional[str] = ..., reason: _Optional[str] = ...) -> None: ...

class RecoverWorkflowExecutionInput(_message.Message):
    __slots__ = ("id", "reason")
    ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    id: str
    reason: str
    def __init__(self, id: _Optional[str] = ..., reason: _Optional[str] = ...) -> None: ...

class PauseWorkflowExecutionInput(_message.Message):
    __slots__ = ("id", "reason")
    ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    id: str
    reason: str
    def __init__(self, id: _Optional[str] = ..., reason: _Optional[str] = ...) -> None: ...

class ResumeWorkflowExecutionInput(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class SendSignalInput(_message.Message):
    __slots__ = ("execution_id", "signal_name", "payload", "idempotency_key")
    EXECUTION_ID_FIELD_NUMBER: _ClassVar[int]
    SIGNAL_NAME_FIELD_NUMBER: _ClassVar[int]
    PAYLOAD_FIELD_NUMBER: _ClassVar[int]
    IDEMPOTENCY_KEY_FIELD_NUMBER: _ClassVar[int]
    execution_id: str
    signal_name: str
    payload: _struct_pb2.Struct
    idempotency_key: str
    def __init__(self, execution_id: _Optional[str] = ..., signal_name: _Optional[str] = ..., payload: _Optional[_Union[_struct_pb2.Struct, _Mapping]] = ..., idempotency_key: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/skill/v1/command.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/skill/v1/command.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.skill.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_api__pb2
from ai.stigmer.agentic.skill.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_skill_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)ai/stigmer/agentic/skill/v1/command.proto\x12\x1b\x61i.stigmer.agentic.skill.v1\x1a%ai/stigmer/agentic/skill/v1/api.proto\x1a$ai/stigmer/agentic/skill/v1/io.proto\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xb4\x05\n\x16SkillCommandController\x12\x99\x01\n\x04push\x12-.ai.stigmer.agentic.skill.v1.PushSkillRequest\x1a\".ai.stigmer.agentic.skill.v1.Skill\">\xc2\xb8\x18:\x08\x15\x10\x1e\"\x03org*/unauthorized to push skill in this organization\x12\xc3\x01\n\x19pushFromExecutionArtifact\x12\x42.ai.stigmer.agentic.skill.v1.PushSkillFromExecutionArtifactRequest\x1a\".ai.stigmer.agentic.skill.v1.Skill\">\xc2\xb8\x18:\x08\x15\x10\x1e\"\x03org*/unauthorized to push skill in this organization\x12\xad\x01\n\x10updateVisibility\x12\x35.ai.stigmer.commons.apiresource.UpdateVisibilityInput\x1a\".ai.stigmer.agentic.skill.v1.Skill\">\xc2\xb8\x18:\x08\x04\x10+\"\x0bresource_id*\'unauthorized to update skill visibility\x12\x81\x01\n\x06\x64\x65lete\x12$.ai.stigmer.agentic.skill.v1.SkillId\x1a\".ai.stigmer.agentic.skill.v1.Skill\"-\xc2\xb8\x18)\x08\x02\x10+\"\x05value*\x1cunauthorized to delete skill\x1a\x04\xa0\xff++B\xc0\x01\n\x1f\x63om.ai.stigmer.agentic.skill.v1B\x0c\x43ommandProtoP\x01\xa2\x02\x04\x41SAS\xaa\x02\x1b\x41i.Stigmer.Agentic.Skill.V1\xca\x02\x1b\x41i\\Stigmer\\Agentic\\Skill\\V1\xe2\x02\'Ai\\Stigmer\\Agentic\\Skill\\V1\\GPBMetadata\xea\x02\x1f\x41i::Stigmer::Agentic::Skill::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.skill.v1.command_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.ai.stigmer.agentic.skill.v1B\014CommandProtoP\001\242\002\004ASAS\252\002\033Ai.Stigmer.Agentic.Skill.V1\312\002\033Ai\\Stigmer\\Agentic\\Skill\\V1\342\002\'Ai\\Stigmer\\Agentic\\Skill\\V1\\GPBMetadata\352\002\037Ai::Stigmer::Agentic::Skill::V1'
  _globals['_SKILLCOMMANDCONTROLLER']._loaded_options = None
  _globals['_SKILLCOMMANDCONTROLLER']._serialized_options = b'\240\377++'
  _globals['_SKILLCOMMANDCONTROLLER'].methods_by_name['push']._loaded_options = None
  _globals['_SKILLCOMMANDCONTROLLER'].methods_by_name['push']._serialized_options = b'\302\270\030:\010\025\020\036\"\003org*/unauthorized to push skill in this organization'
  _globals['_SKILLCOMMANDCONTROLLER'].methods_by_name['pushFromExecutionArtifact']._loaded_options = None
  _globals['_SKILLCOMMANDCONTROLLER'].methods_by_name['pushFromExecutionArtifact']._serialized_options = b'\302\270\030:\010\025\020\036\"\003org*/unauthorized to push skill in this organization'
  _globals['_SKILLCOMMANDCONTROLLER'].methods_by_name['updateVisibility']._loaded_options = None
  _globals['_SKILLCOMMANDCONTROLLER'].methods_by_name['updateVisibility']._serialized_options = b'\302\270\030:\010\004\020+\"\013resource_id*\'unauthorized to update skill visibility'
  _globals['_SKILLCOMMANDCONTROLLER'].methods_by_name['delete']._loaded_options = None
  _globals['_SKILLCOMMANDCONTROLLER'].methods_by_name['delete']._serialized_options = b'\302\270\030)\010\002\020+\"\005value*\034unauthorized to delete skill'
  _globals['_SKILLCOMMANDCONTROLLER']._serialized_start=318
  _globals['_SKILLCOMMANDCONTROLLER']._serialized_end=1010
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ai.stigmer.agentic.agentinstance.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2
from ai.stigmer.agentic.agentinstance.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_io__pb2


class AgentInstanceCommandControllerStub(object):
    """AgentInstanceCommandController handles write operations for agent instances.
    Follows the standard pattern: create, update, delete (no granular field updates).
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.apply = channel.unary_unary(
                '/ai.stigmer.agentic.agentinstance.v1.AgentInstanceCommandController/apply',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.FromString,
                _registered_method=True)
        self.create = channel.unary_unary(
                '/ai.stigmer.agentic.agentinstance.v1.AgentInstanceCommandController/create',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.FromString,
                _registered_method=True)
        self.update = channel.unary_unary(
                '/ai.stigmer.agentic.agentinstance.v1.AgentInstanceCommandController/update',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.FromString,
                _registered_method=True)
        self.delete = channel.unary_unary(
                '/ai.stigmer.agentic.agentinstance.v1.AgentInstanceCommandController/delete',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_io__pb2.AgentInstanceId.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.FromString,
                _registered_method=True)


class AgentInstanceCommandControllerServicer(object):
    """AgentInstanceCommandController handles write operations for agent instances.
    Follows the standard pattern: create, update, delete (no granular field updates).
    """

    def apply(self, request, context):
        """Create or update an agent instance.
        The authorization and state-operation are determined depending on whether the agent instance
        is going to be created or updated which is determined as part of the request execution.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def create(self, request, context):
        """Create a new agent instance with full state.
        Provide organization_id in metadata.org, and complete spec with configuration and secrets.

        Authorization: Uses FGA contextual tuples (handler-level)
        - Checks can_create_instance on parent agent (via spec.agent_id)
        - For org-scoped: Passes contextual tuple agent#organization@organization:target-org
        - FGA evaluates membership via contextual tuple (single authorization check)

        This pattern eliminates redundant checks by providing organization context to FGA
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """Update an instance with full state.
        Used to update entire instance configuration including metadata, spec, and secrets.
        No individual field updates - always provide complete state.
        Authorization: Only owner can update (can_edit permission)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """Delete an agent instance.
        Authorization: Only owner can delete (can_delete permission)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AgentInstanceCommandControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'apply': grpc.unary_unary_rpc_method_handler(
                    servicer.apply,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.SerializeToString,
            ),
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_io__pb2.AgentInstanceId.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.stigmer.agentic.agentinstance.v1.AgentInstanceCommandController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ai.stigmer.agentic.agentinstance.v1.AgentInstanceCommandController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AgentInstanceCommandController(object):
    """AgentInstanceCommandController handles write operations for agent instances.
    Follows the standard pattern: create, update, delete (no granular field updates).
    """

    @staticmethod
    def apply(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentinstance.v1.AgentInstanceCommandController/apply',
            ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentinstance.v1.AgentInstanceCommandController/create',
            ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentinstance.v1.AgentInstanceCommandController/update',
            ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agentinstance.v1.AgentInstanceCommandController/delete',
            ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_io__pb2.AgentInstanceId.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2.AgentInstance.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



from ai.stigmer.agentic.executioncontext.v1 import spec_pb2 as _spec_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AgentExecutionSpec(_message.Message):
    __slots__ = ("session_id", "agent_id", "message", "execution_config", "runtime_env", "callback_token", "auto_approve_all", "parent_workflow_id", "attachments", "workspace_file_refs")
    class RuntimeEnvEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: _spec_pb2.ExecutionValue
        def __init__(self, key: _Optional[str] = ..., value: _Optional[_Union[_spec_pb2.ExecutionValue, _Mapping]] = ...) -> None: ...
    SESSION_ID_FIELD_NUMBER: _ClassVar[int]
    AGENT_ID_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    EXECUTION_CONFIG_FIELD_NUMBER: _ClassVar[int]
    RUNTIME_ENV_FIELD_NUMBER: _ClassVar[int]
    CALLBACK_TOKEN_FIELD_NUMBER: _ClassVar[int]
    AUTO_APPROVE_ALL_FIELD_NUMBER: _ClassVar[int]
    PARENT_WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    ATTACHMENTS_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_FILE_REFS_FIELD_NUMBER: _ClassVar[int]
    session_id: str
    agent_id: str
    message: str
    execution_config: ExecutionConfig
    runtime_env: _containers.MessageMap[str, _spec_pb2.ExecutionValue]
    callback_token: bytes
    auto_approve_all: bool
    parent_workflow_id: str
    attachments: _containers.RepeatedCompositeFieldContainer[Attachment]
    workspace_file_refs: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, session_id: _Optional[str] = ..., agent_id: _Optional[str] = ..., message: _Optional[str] = ..., execution_config: _Optional[_Union[ExecutionConfig, _Mapping]] = ..., runtime_env: _Optional[_Mapping[str, _spec_pb2.ExecutionValue]] = ..., callback_token: _Optional[bytes] = ..., auto_approve_all: bool = ..., parent_workflow_id: _Optional[str] = ..., attachments: _Optional[_Iterable[_Union[Attachment, _Mapping]]] = ..., workspace_file_refs: _Optional[_Iterable[str]] = ...) -> None: ...

class ExecutionConfig(_message.Message):
    __slots__ = ("model_name", "context_management", "max_tool_rounds", "max_tool_result_chars", "max_cost_usd")
    MODEL_NAME_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_MANAGEMENT_FIELD_NUMBER: _ClassVar[int]
    MAX_TOOL_ROUNDS_FIELD_NUMBER: _ClassVar[int]
    MAX_TOOL_RESULT_CHARS_FIELD_NUMBER: _ClassVar[int]
    MAX_COST_USD_FIELD_NUMBER: _ClassVar[int]
    model_name: str
    context_management: ContextManagementConfig
    max_tool_rounds: int
    max_tool_result_chars: int
    max_cost_usd: float
    def __init__(self, model_name: _Optional[str] = ..., context_management: _Optional[_Union[ContextManagementConfig, _Mapping]] = ..., max_tool_rounds: _Optional[int] = ..., max_tool_result_chars: _Optional[int] = ..., max_cost_usd: _Optional[float] = ...) -> None: ...

class ContextManagementConfig(_message.Message):
    __slots__ = ("disable_summarization", "custom_trigger_threshold", "custom_target_tokens")
    DISABLE_SUMMARIZATION_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_TRIGGER_THRESHOLD_FIELD_NUMBER: _ClassVar[int]
    CUSTOM_TARGET_TOKENS_FIELD_NUMBER: _ClassVar[int]
    disable_summarization: bool
    custom_trigger_threshold: int
    custom_target_tokens: int
    def __init__(self, disable_summarization: bool = ..., custom_trigger_threshold: _Optional[int] = ..., custom_target_tokens: _Optional[int] = ...) -> None: ...

class Attachment(_message.Message):
    __slots__ = ("filename", "storage_key", "mount_path", "content_type", "extract", "local_path")
    FILENAME_FIELD_NUMBER: _ClassVar[int]
    STORAGE_KEY_FIELD_NUMBER: _ClassVar[int]
    MOUNT_PATH_FIELD_NUMBER: _ClassVar[int]
    CONTENT_TYPE_FIELD_NUMBER: _ClassVar[int]
    EXTRACT_FIELD_NUMBER: _ClassVar[int]
    LOCAL_PATH_FIELD_NUMBER: _ClassVar[int]
    filename: str
    storage_key: str
    mount_path: str
    content_type: str
    extract: bool
    local_path: str
    def __init__(self, filename: _Optional[str] = ..., storage_key: _Optional[str] = ..., mount_path: _Optional[str] = ..., content_type: _Optional[str] = ..., extract: bool = ..., local_path: _Optional[str] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentexecution/v1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentexecution/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentexecution.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_api__pb2
from ai.stigmer.agentic.agentexecution.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_agentexecution_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0ai/stigmer/agentic/agentexecution/v1/query.proto\x12$ai.stigmer.agentic.agentexecution.v1\x1a.ai/stigmer/agentic/agentexecution/v1/api.proto\x1a-ai/stigmer/agentic/agentexecution/v1/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xf7\x0c\n\x1d\x41gentExecutionQueryController\x12\xa9\x01\n\x03get\x12\x36.ai.stigmer.agentic.agentexecution.v1.AgentExecutionId\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"4\xc2\xb8\x18\x30\x08\x03\x10)\"\x05value*#unauthorized to get agent execution\x12\x88\x01\n\x04list\x12@.ai.stigmer.agentic.agentexecution.v1.ListAgentExecutionsRequest\x1a\x38.ai.stigmer.agentic.agentexecution.v1.AgentExecutionList\"\x04\xd0\xb8\x18\x01\x12\x9a\x01\n\rlistBySession\x12I.ai.stigmer.agentic.agentexecution.v1.ListAgentExecutionsBySessionRequest\x1a\x38.ai.stigmer.agentic.agentexecution.v1.AgentExecutionList\"\x04\xd0\xb8\x18\x01\x12\xba\x01\n\tsubscribe\x12\x36.ai.stigmer.agentic.agentexecution.v1.AgentExecutionId\x1a\x34.ai.stigmer.agentic.agentexecution.v1.AgentExecution\"=\xc2\xb8\x18\x39\x08\x03\x10)\"\x05value*,unauthorized to subscribe to agent execution0\x01\x12\xf3\x01\n\x16getArtifactDownloadUrl\x12\x43.ai.stigmer.agentic.agentexecution.v1.GetArtifactDownloadUrlRequest\x1a\x44.ai.stigmer.agentic.agentexecution.v1.GetArtifactDownloadUrlResponse\"N\xc2\xb8\x18J\x08\x03\x10)\"\x0c\x65xecution_id*6unauthorized to download artifact from agent execution\x12\xeb\x01\n\x12getArtifactContent\x12?.ai.stigmer.agentic.agentexecution.v1.GetArtifactContentRequest\x1a@.ai.stigmer.agentic.agentexecution.v1.GetArtifactContentResponse\"R\xc2\xb8\x18N\x08\x03\x10)\"\x0c\x65xecution_id*:unauthorized to read artifact content from agent execution\x12\xa2\x01\n\x15getSessionUsageReport\x12@.ai.stigmer.agentic.agentexecution.v1.GetSessionUsageReportInput\x1a\x41.ai.stigmer.agentic.agentexecution.v1.GetSessionUsageReportOutput\"\x04\xd0\xb8\x18\x01\x12\x9c\x01\n\x13getAgentUsageReport\x12>.ai.stigmer.agentic.agentexecution.v1.GetAgentUsageReportInput\x1a?.ai.stigmer.agentic.agentexecution.v1.GetAgentUsageReportOutput\"\x04\xd0\xb8\x18\x01\x12\x96\x01\n\x11getOrgUsageReport\x12<.ai.stigmer.agentic.agentexecution.v1.GetOrgUsageReportInput\x1a=.ai.stigmer.agentic.agentexecution.v1.GetOrgUsageReportOutput\"\x04\xd0\xb8\x18\x01\x1a\x04\xa0\xff+)B\xeb\x01\n(com.ai.stigmer.agentic.agentexecution.v1B\nQueryProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02$Ai.Stigmer.Agentic.Agentexecution.V1\xca\x02$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\xea\x02(Ai::Stigmer::Agentic::Agentexecution::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentexecution.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.agentexecution.v1B\nQueryProtoP\001\242\002\004ASAA\252\002$Ai.Stigmer.Agentic.Agentexecution.V1\312\002$Ai\\Stigmer\\Agentic\\Agentexecution\\V1\342\0020Ai\\Stigmer\\Agentic\\Agentexecution\\V1\\GPBMetadata\352\002(Ai::Stigmer::Agentic::Agentexecution::V1'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER']._serialized_options = b'\240\377+)'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['get']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['get']._serialized_options = b'\302\270\0300\010\003\020)\"\005value*#unauthorized to get agent execution'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['list']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['list']._serialized_options = b'\320\270\030\001'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['listBySession']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['listBySession']._serialized_options = b'\320\270\030\001'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['subscribe']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['subscribe']._serialized_options = b'\302\270\0309\010\003\020)\"\005value*,unauthorized to subscribe to agent execution'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getArtifactDownloadUrl']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getArtifactDownloadUrl']._serialized_options = b'\302\270\030J\010\003\020)\"\014execution_id*6unauthorized to download artifact from agent execution'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getArtifactContent']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getArtifactContent']._serialized_options = b'\302\270\030N\010\003\020)\"\014execution_id*:unauthorized to read artifact content from agent execution'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getSessionUsageReport']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getSessionUsageReport']._serialized_options = b'\320\270\030\001'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getAgentUsageReport']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getAgentUsageReport']._serialized_options = b'\320\270\030\001'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getOrgUsageReport']._loaded_options = None
  _globals['_AGENTEXECUTIONQUERYCONTROLLER'].methods_by_name['getOrgUsageReport']._serialized_options = b'\320\270\030\001'
  _globals['_AGENTEXECUTIONQUERYCONTROLLER']._serialized_start=311
  _globals['_AGENTEXECUTIONQUERYCONTROLLER']._serialized_end=1966
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflow/v1/serverless/validation.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflow/v1/serverless/validation.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:ai/stigmer/agentic/workflow/v1/serverless/validation.proto\x12)ai.stigmer.agentic.workflow.v1.serverless\x1a\x1fgoogle/protobuf/timestamp.proto\"\xad\x02\n\x1cServerlessWorkflowValidation\x12P\n\x05state\x18\x01 \x01(\x0e\x32:.ai.stigmer.agentic.workflow.v1.serverless.ValidationStateR\x05state\x12\x12\n\x04yaml\x18\x02 \x01(\tR\x04yaml\x12\x16\n\x06\x65rrors\x18\x03 \x03(\tR\x06\x65rrors\x12\x1a\n\x08warnings\x18\x04 \x03(\tR\x08warnings\x12=\n\x0cvalidated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0bvalidatedAt\x12\x34\n\x16validation_workflow_id\x18\x06 \x01(\tR\x14validationWorkflowId*d\n\x0fValidationState\x12 \n\x1cVALIDATION_STATE_UNSPECIFIED\x10\x00\x12\x0b\n\x07PENDING\x10\x01\x12\t\n\x05VALID\x10\x02\x12\x0b\n\x07INVALID\x10\x03\x12\n\n\x06\x46\x41ILED\x10\x04\x42\x8c\x02\n-com.ai.stigmer.agentic.workflow.v1.serverlessB\x0fValidationProtoP\x01\xa2\x02\x06\x41SAWVS\xaa\x02)Ai.Stigmer.Agentic.Workflow.V1.Serverless\xca\x02)Ai\\Stigmer\\Agentic\\Workflow\\V1\\Serverless\xe2\x02\x35\x41i\\Stigmer\\Agentic\\Workflow\\V1\\Serverless\\GPBMetadata\xea\x02.Ai::Stigmer::Agentic::Workflow::V1::Serverlessb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflow.v1.serverless.validation_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n-com.ai.stigmer.agentic.workflow.v1.serverlessB\017ValidationProtoP\001\242\002\006ASAWVS\252\002)Ai.Stigmer.Agentic.Workflow.V1.Serverless\312\002)Ai\\Stigmer\\Agentic\\Workflow\\V1\\Serverless\342\0025Ai\\Stigmer\\Agentic\\Workflow\\V1\\Serverless\\GPBMetadata\352\002.Ai::Stigmer::Agentic::Workflow::V1::Serverless'
  _globals['_VALIDATIONSTATE']._serialized_start=442
  _globals['_VALIDATIONSTATE']._serialized_end=542
  _globals['_SERVERLESSWORKFLOWVALIDATION']._serialized_start=139
  _globals['_SERVERLESSWORKFLOWVALIDATION']._serialized_end=440
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentinstance/v1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentinstance/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentinstance.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2
from ai.stigmer.agentic.agentinstance.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2
from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/ai/stigmer/agentic/agentinstance/v1/query.proto\x12#ai.stigmer.agentic.agentinstance.v1\x1a-ai/stigmer/agentic/agentinstance/v1/api.proto\x1a,ai/stigmer/agentic/agentinstance/v1/io.proto\x1a\'ai/stigmer/commons/apiresource/io.proto\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xe8\x04\n\x1c\x41gentInstanceQueryController\x12\xa4\x01\n\x03get\x12\x34.ai.stigmer.agentic.agentinstance.v1.AgentInstanceId\x1a\x32.ai.stigmer.agentic.agentinstance.v1.AgentInstance\"3\xc2\xb8\x18/\x08\x03\x10-\"\x05value*\"unauthorized to get Agent Instance\x12\x90\x01\n\ngetByAgent\x12\x44.ai.stigmer.agentic.agentinstance.v1.GetAgentInstancesByAgentRequest\x1a\x36.ai.stigmer.agentic.agentinstance.v1.AgentInstanceList\"\x04\xd0\xb8\x18\x01\x12\x80\x01\n\x0egetByReference\x12\x34.ai.stigmer.commons.apiresource.ApiResourceReference\x1a\x32.ai.stigmer.agentic.agentinstance.v1.AgentInstance\"\x04\xd0\xb8\x18\x01\x12\x84\x01\n\x04list\x12>.ai.stigmer.agentic.agentinstance.v1.ListAgentInstancesRequest\x1a\x36.ai.stigmer.agentic.agentinstance.v1.AgentInstanceList\"\x04\xd0\xb8\x18\x01\x1a\x04\xa0\xff+-B\xe6\x01\n\'com.ai.stigmer.agentic.agentinstance.v1B\nQueryProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02#Ai.Stigmer.Agentic.Agentinstance.V1\xca\x02#Ai\\Stigmer\\Agentic\\Agentinstance\\V1\xe2\x02/Ai\\Stigmer\\Agentic\\Agentinstance\\V1\\GPBMetadata\xea\x02\'Ai::Stigmer::Agentic::Agentinstance::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentinstance.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.ai.stigmer.agentic.agentinstance.v1B\nQueryProtoP\001\242\002\004ASAA\252\002#Ai.Stigmer.Agentic.Agentinstance.V1\312\002#Ai\\Stigmer\\Agentic\\Agentinstance\\V1\342\002/Ai\\Stigmer\\Agentic\\Agentinstance\\V1\\GPBMetadata\352\002\'Ai::Stigmer::Agentic::Agentinstance::V1'
  _globals['_AGENTINSTANCEQUERYCONTROLLER']._loaded_options = None
  _globals['_AGENTINSTANCEQUERYCONTROLLER']._serialized_options = b'\240\377+-'
  _globals['_AGENTINSTANCEQUERYCONTROLLER'].methods_by_name['get']._loaded_options = None
  _globals['_AGENTINSTANCEQUERYCONTROLLER'].methods_by_name['get']._serialized_options = b'\302\270\030/\010\003\020-\"\005value*\"unauthorized to get Agent Instance'
  _globals['_AGENTINSTANCEQUERYCONTROLLER'].methods_by_name['getByAgent']._loaded_options = None
  _globals['_AGENTINSTANCEQUERYCONTROLLER'].methods_by_name['getByAgent']._serialized_options = b'\320\270\030\001'
  _globals['_AGENTINSTANCEQUERYCONTROLLER'].methods_by_name['getByReference']._loaded_options = None
  _globals['_AGENTINSTANCEQUERYCONTROLLER'].methods_by_name['getByReference']._serialized_options = b'\320\270\030\001'
  _globals['_AGENTINSTANCEQUERYCONTROLLER'].methods_by_name['list']._loaded_options = None
  _globals['_AGENTINSTANCEQUERYCONTROLLER'].methods_by_name['list']._serialized_options = b'\320\270\030\001'
  _globals['_AGENTINSTANCEQUERYCONTROLLER']._serialized_start=348
  _globals['_AGENTINSTANCEQUERYCONTROLLER']._serialized_end=964
# @@protoc_insertion_point(module_scope)



from ai.stigmer.commons.apiresource import io_pb2 as _io_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class WorkflowInstanceSpec(_message.Message):
    __slots__ = ("workflow_id", "description", "environment_refs")
    WORKFLOW_ID_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    ENVIRONMENT_REFS_FIELD_NUMBER: _ClassVar[int]
    workflow_id: str
    description: str
    environment_refs: _containers.RepeatedCompositeFieldContainer[_io_pb2.ApiResourceReference]
    def __init__(self, workflow_id: _Optional[str] = ..., description: _Optional[str] = ..., environment_refs: _Optional[_Iterable[_Union[_io_pb2.ApiResourceReference, _Mapping]]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ai.stigmer.agentic.mcpserver.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2
from ai.stigmer.agentic.mcpserver.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2


class McpServerCommandControllerStub(object):
    """McpServerCommandController provides write operations for MCP server resources.
    Supports creating, updating, and deleting MCP server definitions.

    Authorization model for writes:
    - Platform-scoped: Only platform operators can create/modify
    - Organization-scoped: Org admins can create/modify
    - Identity-account-scoped: Only the owner can create/modify

    Primary interface: The `apply` method provides Kubernetes-style idempotent
    create-or-update semantics, which is the recommended approach for CLI usage.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.apply = channel.unary_unary(
                '/ai.stigmer.agentic.mcpserver.v1.McpServerCommandController/apply',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.FromString,
                _registered_method=True)
        self.create = channel.unary_unary(
                '/ai.stigmer.agentic.mcpserver.v1.McpServerCommandController/create',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.FromString,
                _registered_method=True)
        self.update = channel.unary_unary(
                '/ai.stigmer.agentic.mcpserver.v1.McpServerCommandController/update',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.FromString,
                _registered_method=True)
        self.delete = channel.unary_unary(
                '/ai.stigmer.agentic.mcpserver.v1.McpServerCommandController/delete',
                request_serializer=ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.ApiResourceDeleteInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.FromString,
                _registered_method=True)
        self.updateVisibility = channel.unary_unary(
                '/ai.stigmer.agentic.mcpserver.v1.McpServerCommandController/updateVisibility',
                request_serializer=ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.UpdateVisibilityInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.FromString,
                _registered_method=True)
        self.updateDiscoveredCapabilities = channel.unary_unary(
                '/ai.stigmer.agentic.mcpserver.v1.McpServerCommandController/updateDiscoveredCapabilities',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_io__pb2.UpdateDiscoveredCapabilitiesInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.FromString,
                _registered_method=True)


class McpServerCommandControllerServicer(object):
    """McpServerCommandController provides write operations for MCP server resources.
    Supports creating, updating, and deleting MCP server definitions.

    Authorization model for writes:
    - Platform-scoped: Only platform operators can create/modify
    - Organization-scoped: Org admins can create/modify
    - Identity-account-scoped: Only the owner can create/modify

    Primary interface: The `apply` method provides Kubernetes-style idempotent
    create-or-update semantics, which is the recommended approach for CLI usage.
    """

    def apply(self, request, context):
        """Create or update an MCP server resource (Kubernetes-style apply).

        This is the primary interface for MCP server management.
        Behavior:
        - If the resource doesn't exist: Creates a new MCP server
        - If the resource exists: Updates the existing MCP server

        The resource is identified by (scope, org, slug) combination.

        Input: Full McpServer resource with metadata and spec.
        Returns: The created/updated McpServer with system-populated fields.

        Authorization: Custom authorization in handler.
        The handler determines whether this is a create or update operation
        and performs appropriate scope-aware authorization:
        - Create: Requires permission to create in the target scope
        - Update: Requires can_edit on the existing resource
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def create(self, request, context):
        """Create a new MCP server resource.

        Use this when you explicitly want to create a new resource
        and want an error if it already exists.

        Input: McpServer with metadata (scope, org, name/slug) and spec.
        Returns: The created McpServer with system-generated ID and status.

        Authorization: Custom authorization in handler.
        Requires permission to create MCP servers in the specified scope:
        - Platform: Requires platform operator role
        - Organization: Requires org admin role or can_create_mcp_server permission
        - Identity Account: Automatically allowed for the authenticated user
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """Update an existing MCP server resource.

        Input: McpServer with metadata.id populated and updated spec.
        Returns: The updated McpServer.

        Authorization: Requires can_edit permission on the mcp_server resource.
        Only the owner (based on scope) can update:
        - Platform: Platform operators
        - Organization: Org admins or resource owner
        - Identity Account: The owner
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """Delete an MCP server resource.

        Permanently removes the MCP server definition.
        Agents referencing this MCP server will need to be updated.

        Input: ApiResourceDeleteInput with resource_id and optional version_message.
        Returns: The deleted McpServer (for confirmation/audit).

        Authorization: Requires can_delete permission on the mcp_server resource.
        Only the owner can delete:
        - Platform: Platform operators
        - Organization: Org admins or resource owner
        - Identity Account: The owner
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateVisibility(self, request, context):
        """Update the visibility of an existing MCP server.

        This is a targeted metadata update — it only modifies metadata.visibility,
        leaving spec, status, and other metadata fields untouched. Use this to
        make an MCP server publicly accessible (marketplace-style sharing) or to
        revoke public access without sending the entire resource.

        Authorization: Requires can_edit permission on the mcp_server resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateDiscoveredCapabilities(self, request, context):
        """Update the discovered capabilities (tools and resource templates) for an MCP server.

        This is a targeted status update — it only modifies status.discovered_capabilities,
        leaving spec, validation state, and other status fields untouched.

        Typical flow:
        1. CLI calls getByReference(org/slug) to fetch the McpServer and its ID
        2. CLI connects to the MCP server locally and queries tools/resources
        3. CLI calls this RPC with the ID and discovered capabilities

        Input: UpdateDiscoveredCapabilitiesInput with mcp_server_id and discovered_capabilities.
        Returns: The updated McpServer with the new discovered capabilities.

        Authorization: Requires can_edit permission on the mcp_server resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_McpServerCommandControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'apply': grpc.unary_unary_rpc_method_handler(
                    servicer.apply,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.SerializeToString,
            ),
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.ApiResourceDeleteInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.SerializeToString,
            ),
            'updateVisibility': grpc.unary_unary_rpc_method_handler(
                    servicer.updateVisibility,
                    request_deserializer=ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.UpdateVisibilityInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.SerializeToString,
            ),
            'updateDiscoveredCapabilities': grpc.unary_unary_rpc_method_handler(
                    servicer.updateDiscoveredCapabilities,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_io__pb2.UpdateDiscoveredCapabilitiesInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.stigmer.agentic.mcpserver.v1.McpServerCommandController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ai.stigmer.agentic.mcpserver.v1.McpServerCommandController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class McpServerCommandController(object):
    """McpServerCommandController provides write operations for MCP server resources.
    Supports creating, updating, and deleting MCP server definitions.

    Authorization model for writes:
    - Platform-scoped: Only platform operators can create/modify
    - Organization-scoped: Org admins can create/modify
    - Identity-account-scoped: Only the owner can create/modify

    Primary interface: The `apply` method provides Kubernetes-style idempotent
    create-or-update semantics, which is the recommended approach for CLI usage.
    """

    @staticmethod
    def apply(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.mcpserver.v1.McpServerCommandController/apply',
            ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.mcpserver.v1.McpServerCommandController/create',
            ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.mcpserver.v1.McpServerCommandController/update',
            ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.mcpserver.v1.McpServerCommandController/delete',
            ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.ApiResourceDeleteInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateVisibility(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.mcpserver.v1.McpServerCommandController/updateVisibility',
            ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.UpdateVisibilityInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateDiscoveredCapabilities(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.mcpserver.v1.McpServerCommandController/updateDiscoveredCapabilities',
            ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_io__pb2.UpdateDiscoveredCapabilitiesInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_mcpserver_dot_v1_dot_api__pb2.McpServer.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/agentinstance/v1/io.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/agentinstance/v1/io.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.agentinstance.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_agentinstance_dot_v1_dot_api__pb2
from ai.stigmer.commons.rpc import pagination_pb2 as ai_dot_stigmer_dot_commons_dot_rpc_dot_pagination__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ai/stigmer/agentic/agentinstance/v1/io.proto\x12#ai.stigmer.agentic.agentinstance.v1\x1a-ai/stigmer/agentic/agentinstance/v1/api.proto\x1a\'ai/stigmer/commons/rpc/pagination.proto\x1a\x1b\x62uf/validate/validate.proto\"/\n\x0f\x41gentInstanceId\x12\x1c\n\x05value\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x05value\"\x83\x01\n\x1fGetAgentInstancesByAgentRequest\x12!\n\x08\x61gent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x07\x61gentId\x12=\n\tpage_info\x18\x02 \x01(\x0b\x32 .ai.stigmer.commons.rpc.PageInfoR\x08pageInfo\"~\n\x11\x41gentInstanceList\x12\x1f\n\x0btotal_count\x18\x01 \x01(\x05R\ntotalCount\x12H\n\x05items\x18\x02 \x03(\x0b\x32\x32.ai.stigmer.agentic.agentinstance.v1.AgentInstanceR\x05items\"\x94\x02\n\x19ListAgentInstancesRequest\x12\x19\n\x03org\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x03org\x12\x62\n\x06labels\x18\x02 \x03(\x0b\x32J.ai.stigmer.agentic.agentinstance.v1.ListAgentInstancesRequest.LabelsEntryR\x06labels\x12=\n\tpage_info\x18\x03 \x01(\x0b\x32 .ai.stigmer.commons.rpc.PageInfoR\x08pageInfo\x1a\x39\n\x0bLabelsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x42\xe3\x01\n\'com.ai.stigmer.agentic.agentinstance.v1B\x07IoProtoP\x01\xa2\x02\x04\x41SAA\xaa\x02#Ai.Stigmer.Agentic.Agentinstance.V1\xca\x02#Ai\\Stigmer\\Agentic\\Agentinstance\\V1\xe2\x02/Ai\\Stigmer\\Agentic\\Agentinstance\\V1\\GPBMetadata\xea\x02\'Ai::Stigmer::Agentic::Agentinstance::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.agentinstance.v1.io_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\'com.ai.stigmer.agentic.agentinstance.v1B\007IoProtoP\001\242\002\004ASAA\252\002#Ai.Stigmer.Agentic.Agentinstance.V1\312\002#Ai\\Stigmer\\Agentic\\Agentinstance\\V1\342\002/Ai\\Stigmer\\Agentic\\Agentinstance\\V1\\GPBMetadata\352\002\'Ai::Stigmer::Agentic::Agentinstance::V1'
  _globals['_AGENTINSTANCEID'].fields_by_name['value']._loaded_options = None
  _globals['_AGENTINSTANCEID'].fields_by_name['value']._serialized_options = b'\272H\003\310\001\001'
  _globals['_GETAGENTINSTANCESBYAGENTREQUEST'].fields_by_name['agent_id']._loaded_options = None
  _globals['_GETAGENTINSTANCESBYAGENTREQUEST'].fields_by_name['agent_id']._serialized_options = b'\272H\003\310\001\001'
  _globals['_LISTAGENTINSTANCESREQUEST_LABELSENTRY']._loaded_options = None
  _globals['_LISTAGENTINSTANCESREQUEST_LABELSENTRY']._serialized_options = b'8\001'
  _globals['_LISTAGENTINSTANCESREQUEST'].fields_by_name['org']._loaded_options = None
  _globals['_LISTAGENTINSTANCESREQUEST'].fields_by_name['org']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_AGENTINSTANCEID']._serialized_start=202
  _globals['_AGENTINSTANCEID']._serialized_end=249
  _globals['_GETAGENTINSTANCESBYAGENTREQUEST']._serialized_start=252
  _globals['_GETAGENTINSTANCESBYAGENTREQUEST']._serialized_end=383
  _globals['_AGENTINSTANCELIST']._serialized_start=385
  _globals['_AGENTINSTANCELIST']._serialized_end=511
  _globals['_LISTAGENTINSTANCESREQUEST']._serialized_start=514
  _globals['_LISTAGENTINSTANCESREQUEST']._serialized_end=790
  _globals['_LISTAGENTINSTANCESREQUEST_LABELSENTRY']._serialized_start=733
  _globals['_LISTAGENTINSTANCESREQUEST_LABELSENTRY']._serialized_end=790
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from ai.stigmer.agentic.agent.v1 import api_pb2 as ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2
from ai.stigmer.agentic.agent.v1 import io_pb2 as ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_io__pb2
from ai.stigmer.commons.apiresource import io_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2


class AgentCommandControllerStub(object):
    """AgentCommandController handles write operations for AI agents.
    """

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.apply = channel.unary_unary(
                '/ai.stigmer.agentic.agent.v1.AgentCommandController/apply',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.FromString,
                _registered_method=True)
        self.create = channel.unary_unary(
                '/ai.stigmer.agentic.agent.v1.AgentCommandController/create',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.FromString,
                _registered_method=True)
        self.update = channel.unary_unary(
                '/ai.stigmer.agentic.agent.v1.AgentCommandController/update',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.FromString,
                _registered_method=True)
        self.updateVisibility = channel.unary_unary(
                '/ai.stigmer.agentic.agent.v1.AgentCommandController/updateVisibility',
                request_serializer=ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.UpdateVisibilityInput.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.FromString,
                _registered_method=True)
        self.delete = channel.unary_unary(
                '/ai.stigmer.agentic.agent.v1.AgentCommandController/delete',
                request_serializer=ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_io__pb2.AgentId.SerializeToString,
                response_deserializer=ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.FromString,
                _registered_method=True)


class AgentCommandControllerServicer(object):
    """AgentCommandController handles write operations for AI agents.
    """

    def apply(self, request, context):
        """Create or update an agent.
        The authorization and state-operation are determined depending on whether the agent
        is going to be created or updated which is determined as part of the request execution.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def create(self, request, context):
        """Create a new agent.

        Authorization:
        - Organization-scoped agents: Caller must have can_create_agent permission in the organization
        - Platform-scoped agents: Caller must be a platform operator (handled automatically by common auth step)
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """Update an existing agent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def updateVisibility(self, request, context):
        """Update the visibility of an existing agent.

        This is a targeted metadata update — it only modifies metadata.visibility,
        leaving spec, status, and other metadata fields untouched. Use this to
        make an agent publicly accessible or to revoke public access without
        sending the entire agent resource (avoiding read-modify-write races).

        Authorization: Requires can_edit permission on the agent resource.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """Delete an agent.
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AgentCommandControllerServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'apply': grpc.unary_unary_rpc_method_handler(
                    servicer.apply,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.SerializeToString,
            ),
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.SerializeToString,
            ),
            'updateVisibility': grpc.unary_unary_rpc_method_handler(
                    servicer.updateVisibility,
                    request_deserializer=ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.UpdateVisibilityInput.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_io__pb2.AgentId.FromString,
                    response_serializer=ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'ai.stigmer.agentic.agent.v1.AgentCommandController', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('ai.stigmer.agentic.agent.v1.AgentCommandController', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class AgentCommandController(object):
    """AgentCommandController handles write operations for AI agents.
    """

    @staticmethod
    def apply(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agent.v1.AgentCommandController/apply',
            ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agent.v1.AgentCommandController/create',
            ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agent.v1.AgentCommandController/update',
            ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def updateVisibility(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agent.v1.AgentCommandController/updateVisibility',
            ai_dot_stigmer_dot_commons_dot_apiresource_dot_io__pb2.UpdateVisibilityInput.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/ai.stigmer.agentic.agent.v1.AgentCommandController/delete',
            ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_io__pb2.AgentId.SerializeToString,
            ai_dot_stigmer_dot_agentic_dot_agent_dot_v1_dot_api__pb2.Agent.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/mcpserver/v1/spec.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/mcpserver/v1/spec.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.agentic.environment.v1 import spec_pb2 as ai_dot_stigmer_dot_agentic_dot_environment_dot_v1_dot_spec__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*ai/stigmer/agentic/mcpserver/v1/spec.proto\x12\x1f\x61i.stigmer.agentic.mcpserver.v1\x1a,ai/stigmer/agentic/environment/v1/spec.proto\x1a\x1b\x62uf/validate/validate.proto\"\xf9\x03\n\rMcpServerSpec\x12 \n\x0b\x64\x65scription\x18\x01 \x01(\tR\x0b\x64\x65scription\x12\x19\n\x08icon_url\x18\x02 \x01(\tR\x07iconUrl\x12\x12\n\x04tags\x18\x03 \x03(\tR\x04tags\x12J\n\x05stdio\x18\x04 \x01(\x0b\x32\x32.ai.stigmer.agentic.mcpserver.v1.StdioServerConfigH\x00R\x05stdio\x12G\n\x04http\x18\x05 \x01(\x0b\x32\x31.ai.stigmer.agentic.mcpserver.v1.HttpServerConfigH\x00R\x04http\x12\x32\n\x15\x64\x65\x66\x61ult_enabled_tools\x18\x07 \x03(\tR\x13\x64\x65\x66\x61ultEnabledTools\x12M\n\x08\x65nv_spec\x18\x08 \x01(\x0b\x32\x32.ai.stigmer.agentic.environment.v1.EnvironmentSpecR\x07\x65nvSpec\x12i\n\x16\x64\x65\x66\x61ult_tool_approvals\x18\t \x03(\x0b\x32\x33.ai.stigmer.agentic.mcpserver.v1.ToolApprovalPolicyR\x14\x64\x65\x66\x61ultToolApprovalsB\x14\n\x0bserver_type\x12\x05\xbaH\x02\x08\x01\"j\n\x11StdioServerConfig\x12 \n\x07\x63ommand\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x07\x63ommand\x12\x12\n\x04\x61rgs\x18\x02 \x03(\tR\x04\x61rgs\x12\x1f\n\x0bworking_dir\x18\x03 \x01(\tR\nworkingDir\"\xa3\x03\n\x10HttpServerConfig\x12\x1d\n\x03url\x18\x01 \x01(\tB\x0b\xbaH\x08r\x03\x88\x01\x01\xc8\x01\x01R\x03url\x12X\n\x07headers\x18\x02 \x03(\x0b\x32>.ai.stigmer.agentic.mcpserver.v1.HttpServerConfig.HeadersEntryR\x07headers\x12\x65\n\x0cquery_params\x18\x03 \x03(\x0b\x32\x42.ai.stigmer.agentic.mcpserver.v1.HttpServerConfig.QueryParamsEntryR\x0bqueryParams\x12\x33\n\x0ftimeout_seconds\x18\x04 \x01(\x05\x42\n\xbaH\x07\x1a\x05\x18\xac\x02(\x00R\x0etimeoutSeconds\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a>\n\x10QueryParamsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\"T\n\x12ToolApprovalPolicy\x12$\n\ttool_name\x18\x01 \x01(\tB\x07\xbaH\x04r\x02\x10\x01R\x08toolName\x12\x18\n\x07message\x18\x02 \x01(\tR\x07messageB\xd1\x01\n#com.ai.stigmer.agentic.mcpserver.v1B\tSpecProtoP\x01\xa2\x02\x04\x41SAM\xaa\x02\x1f\x41i.Stigmer.Agentic.Mcpserver.V1\xca\x02\x1f\x41i\\Stigmer\\Agentic\\Mcpserver\\V1\xe2\x02+Ai\\Stigmer\\Agentic\\Mcpserver\\V1\\GPBMetadata\xea\x02#Ai::Stigmer::Agentic::Mcpserver::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.mcpserver.v1.spec_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n#com.ai.stigmer.agentic.mcpserver.v1B\tSpecProtoP\001\242\002\004ASAM\252\002\037Ai.Stigmer.Agentic.Mcpserver.V1\312\002\037Ai\\Stigmer\\Agentic\\Mcpserver\\V1\342\002+Ai\\Stigmer\\Agentic\\Mcpserver\\V1\\GPBMetadata\352\002#Ai::Stigmer::Agentic::Mcpserver::V1'
  _globals['_MCPSERVERSPEC'].oneofs_by_name['server_type']._loaded_options = None
  _globals['_MCPSERVERSPEC'].oneofs_by_name['server_type']._serialized_options = b'\272H\002\010\001'
  _globals['_STDIOSERVERCONFIG'].fields_by_name['command']._loaded_options = None
  _globals['_STDIOSERVERCONFIG'].fields_by_name['command']._serialized_options = b'\272H\003\310\001\001'
  _globals['_HTTPSERVERCONFIG_HEADERSENTRY']._loaded_options = None
  _globals['_HTTPSERVERCONFIG_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_HTTPSERVERCONFIG_QUERYPARAMSENTRY']._loaded_options = None
  _globals['_HTTPSERVERCONFIG_QUERYPARAMSENTRY']._serialized_options = b'8\001'
  _globals['_HTTPSERVERCONFIG'].fields_by_name['url']._loaded_options = None
  _globals['_HTTPSERVERCONFIG'].fields_by_name['url']._serialized_options = b'\272H\010r\003\210\001\001\310\001\001'
  _globals['_HTTPSERVERCONFIG'].fields_by_name['timeout_seconds']._loaded_options = None
  _globals['_HTTPSERVERCONFIG'].fields_by_name['timeout_seconds']._serialized_options = b'\272H\007\032\005\030\254\002(\000'
  _globals['_TOOLAPPROVALPOLICY'].fields_by_name['tool_name']._loaded_options = None
  _globals['_TOOLAPPROVALPOLICY'].fields_by_name['tool_name']._serialized_options = b'\272H\004r\002\020\001'
  _globals['_MCPSERVERSPEC']._serialized_start=155
  _globals['_MCPSERVERSPEC']._serialized_end=660
  _globals['_STDIOSERVERCONFIG']._serialized_start=662
  _globals['_STDIOSERVERCONFIG']._serialized_end=768
  _globals['_HTTPSERVERCONFIG']._serialized_start=771
  _globals['_HTTPSERVERCONFIG']._serialized_end=1190
  _globals['_HTTPSERVERCONFIG_HEADERSENTRY']._serialized_start=1068
  _globals['_HTTPSERVERCONFIG_HEADERSENTRY']._serialized_end=1126
  _globals['_HTTPSERVERCONFIG_QUERYPARAMSENTRY']._serialized_start=1128
  _globals['_HTTPSERVERCONFIG_QUERYPARAMSENTRY']._serialized_end=1190
  _globals['_TOOLAPPROVALPOLICY']._serialized_start=1192
  _globals['_TOOLAPPROVALPOLICY']._serialized_end=1276
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/agentic/workflow/v1/tasks/http_call.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/agentic/workflow/v1/tasks/http_call.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import field_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_field__options__pb2
from buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4ai/stigmer/agentic/workflow/v1/tasks/http_call.proto\x12$ai.stigmer.agentic.workflow.v1.tasks\x1a\x32\x61i/stigmer/commons/apiresource/field_options.proto\x1a\x1b\x62uf/validate/validate.proto\x1a\x1cgoogle/protobuf/struct.proto\"\xbb\x03\n\x12HttpCallTaskConfig\x12?\n\x06method\x18\x01 \x01(\tB\'\xbaH$r\x1fR\x03GETR\x04POSTR\x03PUTR\x06\x44\x45LETER\x05PATCH\xc8\x01\x01R\x06method\x12V\n\x08\x65ndpoint\x18\x02 \x01(\x0b\x32\x32.ai.stigmer.agentic.workflow.v1.tasks.HttpEndpointB\x06\xbaH\x03\xc8\x01\x01R\x08\x65ndpoint\x12_\n\x07headers\x18\x03 \x03(\x0b\x32\x45.ai.stigmer.agentic.workflow.v1.tasks.HttpCallTaskConfig.HeadersEntryR\x07headers\x12+\n\x04\x62ody\x18\x04 \x01(\x0b\x32\x17.google.protobuf.StructR\x04\x62ody\x12\x33\n\x0ftimeout_seconds\x18\x05 \x01(\x05\x42\n\xbaH\x07\x1a\x05\x18\xac\x02(\x01R\x0etimeoutSeconds\x1a:\n\x0cHeadersEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01:\r\xea\x8b,\thttp_call\"0\n\x0cHttpEndpoint\x12 \n\x03uri\x18\x01 \x01(\tB\x0e\xbaH\x07r\x02\x10\x01\xc8\x01\x01\xd8\x85,\x01R\x03uriB\xf1\x01\n(com.ai.stigmer.agentic.workflow.v1.tasksB\rHttpCallProtoP\x01\xa2\x02\x06\x41SAWVT\xaa\x02$Ai.Stigmer.Agentic.Workflow.V1.Tasks\xca\x02$Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\xe2\x02\x30\x41i\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\\GPBMetadata\xea\x02)Ai::Stigmer::Agentic::Workflow::V1::Tasksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.agentic.workflow.v1.tasks.http_call_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n(com.ai.stigmer.agentic.workflow.v1.tasksB\rHttpCallProtoP\001\242\002\006ASAWVT\252\002$Ai.Stigmer.Agentic.Workflow.V1.Tasks\312\002$Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\342\0020Ai\\Stigmer\\Agentic\\Workflow\\V1\\Tasks\\GPBMetadata\352\002)Ai::Stigmer::Agentic::Workflow::V1::Tasks'
  _globals['_HTTPCALLTASKCONFIG_HEADERSENTRY']._loaded_options = None
  _globals['_HTTPCALLTASKCONFIG_HEADERSENTRY']._serialized_options = b'8\001'
  _globals['_HTTPCALLTASKCONFIG'].fields_by_name['method']._loaded_options = None
  _globals['_HTTPCALLTASKCONFIG'].fields_by_name['method']._serialized_options = b'\272H$r\037R\003GETR\004POSTR\003PUTR\006DELETER\005PATCH\310\001\001'
  _globals['_HTTPCALLTASKCONFIG'].fields_by_name['endpoint']._loaded_options = None
  _globals['_HTTPCALLTASKCONFIG'].fields_by_name['endpoint']._serialized_options = b'\272H\003\310\001\001'
  _globals['_HTTPCALLTASKCONFIG'].fields_by_name['timeout_seconds']._loaded_options = None
  _globals['_HTTPCALLTASKCONFIG'].fields_by_name['timeout_seconds']._serialized_options = b'\272H\007\032\005\030\254\002(\001'
  _globals['_HTTPCALLTASKCONFIG']._loaded_options = None
  _globals['_HTTPCALLTASKCONFIG']._serialized_options = b'\352\213,\thttp_call'
  _globals['_HTTPENDPOINT'].fields_by_name['uri']._loaded_options = None
  _globals['_HTTPENDPOINT'].fields_by_name['uri']._serialized_options = b'\272H\007r\002\020\001\310\001\001\330\205,\001'
  _globals['_HTTPCALLTASKCONFIG']._serialized_start=206
  _globals['_HTTPCALLTASKCONFIG']._serialized_end=649
  _globals['_HTTPCALLTASKCONFIG_HEADERSENTRY']._serialized_start=576
  _globals['_HTTPCALLTASKCONFIG_HEADERSENTRY']._serialized_end=634
  _globals['_HTTPENDPOINT']._serialized_start=651
  _globals['_HTTPENDPOINT']._serialized_end=699
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: ai/stigmer/iam/iampolicy/v1/query.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'ai/stigmer/iam/iampolicy/v1/query.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ai.stigmer.commons.apiresource import rpc_service_options_pb2 as ai_dot_stigmer_dot_commons_dot_apiresource_dot_rpc__service__options__pb2
from ai.stigmer.iam.iampolicy.v1 import api_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_api__pb2
from ai.stigmer.iam.iampolicy.v1 import io_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_io__pb2
from ai.stigmer.iam.iampolicy.v1.rpcauthorization import method_options_pb2 as ai_dot_stigmer_dot_iam_dot_iampolicy_dot_v1_dot_rpcauthorization_dot_method__options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'ai/stigmer/iam/iampolicy/v1/query.proto\x12\x1b\x61i.stigmer.iam.iampolicy.v1\x1a\x38\x61i/stigmer/commons/apiresource/rpc_service_options.proto\x1a%ai/stigmer/iam/iampolicy/v1/api.proto\x1a$ai/stigmer/iam/iampolicy/v1/io.proto\x1a\x41\x61i/stigmer/iam/iampolicy/v1/rpcauthorization/method_options.proto2\xc8\x05\n\x18IamPolicyQueryController\x12\x85\x01\n\x03get\x12(.ai.stigmer.iam.iampolicy.v1.IamPolicyId\x1a&.ai.stigmer.iam.iampolicy.v1.IamPolicy\",\xc2\xb8\x18(\x08\t*$unauthorized to view access policies\x12\x87\x01\n\x12\x63heckAuthorization\x12\x34.ai.stigmer.iam.iampolicy.v1.CheckAuthorizationInput\x1a\x35.ai.stigmer.iam.iampolicy.v1.CheckAuthorizationResult\"\x04\xd0\xb8\x18\x01\x12\xc6\x01\n\x19listAuthorizedResourceIds\x12;.ai.stigmer.iam.iampolicy.v1.ListAuthorizedResourceIdsInput\x1a\x36.ai.stigmer.iam.iampolicy.v1.AuthorizedResourceIdsList\"4\xc2\xb8\x18\x30\x08\t*,unauthorized to view authorized resource ids\x12\xca\x01\n\x1alistAuthorizedPrincipalIds\x12<.ai.stigmer.iam.iampolicy.v1.ListAuthorizedPrincipalIdsInput\x1a\x37.ai.stigmer.iam.iampolicy.v1.AuthorizedPrincipalIdsList\"5\xc2\xb8\x18\x31\x08\t*-unauthorized to view authorized principal ids\x1a\x04\xa0\xff+\nB\xbe\x01\n\x1f\x63om.ai.stigmer.iam.iampolicy.v1B\nQueryProtoP\x01\xa2\x02\x04\x41SII\xaa\x02\x1b\x41i.Stigmer.Iam.Iampolicy.V1\xca\x02\x1b\x41i\\Stigmer\\Iam\\Iampolicy\\V1\xe2\x02\'Ai\\Stigmer\\Iam\\Iampolicy\\V1\\GPBMetadata\xea\x02\x1f\x41i::Stigmer::Iam::Iampolicy::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.stigmer.iam.iampolicy.v1.query_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\037com.ai.stigmer.iam.iampolicy.v1B\nQueryProtoP\001\242\002\004ASII\252\002\033Ai.Stigmer.Iam.Iampolicy.V1\312\002\033Ai\\Stigmer\\Iam\\Iampolicy\\V1\342\002\'Ai\\Stigmer\\Iam\\Iampolicy\\V1\\GPBMetadata\352\002\037Ai::Stigmer::Iam::Iampolicy::V1'
  _globals['_IAMPOLICYQUERYCONTROLLER']._loaded_options = None
  _globals['_IAMPOLICYQUERYCONTROLLER']._serialized_options = b'\240\377+\n'
  _globals['_IAMPOLICYQUERYCONTROLLER'].methods_by_name['get']._loaded_options = None
  _globals['_IAMPOLICYQUERYCONTROLLER'].methods_by_name['get']._serialized_options = b'\302\270\030(\010\t*$unauthorized to view access policies'
  _globals['_IAMPOLICYQUERYCONTROLLER'].methods_by_name['checkAuthorization']._loaded_options = None
  _globals['_IAMPOLICYQUERYCONTROLLER'].methods_by_name['checkAuthorization']._serialized_options = b'\320\270\030\001'
  _globals['_IAMPOLICYQUERYCONTROLLER'].methods_by_name['listAuthorizedResourceIds']._loaded_options = None
  _globals['_IAMPOLICYQUERYCONTROLLER'].methods_by_name['listAuthorizedResourceIds']._serialized_options = b'\302\270\0300\010\t*,unauthorized to view authorized resource ids'
  _globals['_IAMPOLICYQUERYCONTROLLER'].methods_by_name['listAuthorizedPrincipalIds']._loaded_options = None
  _globals['_IAMPOLICYQUERYCONTROLLER'].methods_by_name['listAuthorizedPrincipalIds']._serialized_options = b'\302\270\0301\010\t*-unauthorized to view authorized principal ids'
  _globals['_IAMPOLICYQUERYCONTROLLER']._serialized_start=275
  _globals['_IAMPOLICYQUERYCONTROLLER']._serialized_end=987
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class ApiResourceEventType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    unspecified: _ClassVar[ApiResourceEventType]
    created: _ClassVar[ApiResourceEventType]
    updated: _ClassVar[ApiResourceEventType]
    deleted: _ClassVar[ApiResourceEventType]
    renamed: _ClassVar[ApiResourceEventType]
    stack_outputs_updated: _ClassVar[ApiResourceEventType]

class ApiResourceStateOperationType(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    api_resource_state_operation_type_unspecified: _ClassVar[ApiResourceStateOperationType]
    create: _ClassVar[ApiResourceStateOperationType]
    update: _ClassVar[ApiResourceStateOperationType]
    delete: _ClassVar[ApiResourceStateOperationType]
    read: _ClassVar[ApiResourceStateOperationType]
    stream: _ClassVar[ApiResourceStateOperationType]

class ApiResourceVisibility(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    api_resource_visibility_unspecified: _ClassVar[ApiResourceVisibility]
    visibility_private: _ClassVar[ApiResourceVisibility]
    visibility_public: _ClassVar[ApiResourceVisibility]
unspecified: ApiResourceEventType
created: ApiResourceEventType
updated: ApiResourceEventType
deleted: ApiResourceEventType
renamed: ApiResourceEventType
stack_outputs_updated: ApiResourceEventType
api_resource_state_operation_type_unspecified: ApiResourceStateOperationType
create: ApiResourceStateOperationType
update: ApiResourceStateOperationType
delete: ApiResourceStateOperationType
read: ApiResourceStateOperationType
stream: ApiResourceStateOperationType
api_resource_visibility_unspecified: ApiResourceVisibility
visibility_private: ApiResourceVisibility
visibility_public: ApiResourceVisibility



import datetime

from google.protobuf import timestamp_pb2 as _timestamp_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ApiResourceAuditStatus(_message.Message):
    __slots__ = ("audit",)
    AUDIT_FIELD_NUMBER: _ClassVar[int]
    audit: ApiResourceAudit
    def __init__(self, audit: _Optional[_Union[ApiResourceAudit, _Mapping]] = ...) -> None: ...

class ApiResourceAudit(_message.Message):
    __slots__ = ("spec_audit", "status_audit")
    SPEC_AUDIT_FIELD_NUMBER: _ClassVar[int]
    STATUS_AUDIT_FIELD_NUMBER: _ClassVar[int]
    spec_audit: ApiResourceAuditInfo
    status_audit: ApiResourceAuditInfo
    def __init__(self, spec_audit: _Optional[_Union[ApiResourceAuditInfo, _Mapping]] = ..., status_audit: _Optional[_Union[ApiResourceAuditInfo, _Mapping]] = ...) -> None: ...

class ApiResourceAuditInfo(_message.Message):
    __slots__ = ("created_by", "created_at", "updated_by", "updated_at", "event")
    CREATED_BY_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_BY_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    EVENT_FIELD_NUMBER: _ClassVar[int]
    created_by: ApiResourceAuditActor
    created_at: _timestamp_pb2.Timestamp
    updated_by: ApiResourceAuditActor
    updated_at: _timestamp_pb2.Timestamp
    event: str
    def __init__(self, created_by: _Optional[_Union[ApiResourceAuditActor, _Mapping]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_by: _Optional[_Union[ApiResourceAuditActor, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., event: _Optional[str] = ...) -> None: ...

class ApiResourceAuditActor(_message.Message):
    __slots__ = ("id", "avatar")
    ID_FIELD_NUMBER: _ClassVar[int]
    AVATAR_FIELD_NUMBER: _ClassVar[int]
    id: str
    avatar: str
    def __init__(self, id: _Optional[str] = ..., avatar: _Optional[str] = ...) -> None: ...



from ai.stigmer.agentic.agentexecution.v1 import spec_pb2 as _spec_pb2
from ai.stigmer.commons.apiresource import field_options_pb2 as _field_options_pb2
from buf.validate import validate_pb2 as _validate_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class AgentCallTaskConfig(_message.Message):
    __slots__ = ("agent", "org", "message", "env", "config")
    class EnvEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    AGENT_FIELD_NUMBER: _ClassVar[int]
    ORG_FIELD_NUMBER: _ClassVar[int]
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    ENV_FIELD_NUMBER: _ClassVar[int]
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    agent: str
    org: str
    message: str
    env: _containers.ScalarMap[str, str]
    config: AgentExecutionConfig
    def __init__(self, agent: _Optional[str] = ..., org: _Optional[str] = ..., message: _Optional[str] = ..., env: _Optional[_Mapping[str, str]] = ..., config: _Optional[_Union[AgentExecutionConfig, _Mapping]] = ...) -> None: ...

class AgentExecutionConfig(_message.Message):
    __slots__ = ("model", "timeout", "temperature", "context_management")
    MODEL_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    TEMPERATURE_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_MANAGEMENT_FIELD_NUMBER: _ClassVar[int]
    model: str
    timeout: int
    temperature: float
    context_management: _spec_pb2.ContextManagementConfig
    def __init__(self, model: _Optional[str] = ..., timeout: _Optional[int] = ..., temperature: _Optional[float] = ..., context_management: _Optional[_Union[_spec_pb2.ContextManagementConfig, _Mapping]] = ...) -> None: ...



from google.protobuf.internal import containers as _containers
from google.protobuf.internal import well_known_types as _well_known_types
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable
from typing import ClassVar as _ClassVar, Optional as _Optional

DESCRIPTOR: _descriptor.FileDescriptor

class FieldMask(_message.Message, _well_known_types.FieldMask):
    __slots__ = ("paths",)
    PATHS_FIELD_NUMBER: _ClassVar[int]
    paths: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, paths: _Optional[_Iterable[str]] = ...) -> None: ...
